# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.knowledge_extract_api import KnowledgeExtractApi


class TestKnowledgeExtractApi(unittest.TestCase):
    """KnowledgeExtractApi unit test stubs"""

    def setUp(self) -> None:
        self.api = KnowledgeExtractApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_knowledge_extract_customer_get(self) -> None:
        """Test case for api_v1_knowledge_extract_customer_get

        Get Knowledge Customers
        """
        pass

    def test_api_v1_knowledge_extract_order_get(self) -> None:
        """Test case for api_v1_knowledge_extract_order_get

        Get Knowledge Orders
        """
        pass

    def test_api_v1_knowledge_extract_product_get(self) -> None:
        """Test case for api_v1_knowledge_extract_product_get

        Get Knowledge Products
        """
        pass

    def test_api_v1_knowledge_extract_store_get(self) -> None:
        """Test case for api_v1_knowledge_extract_store_get

        Get Knowledge Stores
        """
        pass


if __name__ == '__main__':
    unittest.main()
